# Human Ethical Dilemmas Repository

A structured GitHub repository to catalog common ethical dilemmas humans face, pairing each dilemma with a poetic **scroll** and a structured **guideline** back-end.
